@@ -26,12 +26,13 @@
 #  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 #  SUCH DAMAGE.
 
-# $XFree86: doctools/sgmlformat/sgmlfmt/sgmlfmt.pl,v 1.19 2003/10/19 19:37:32 dawes Exp $
+# $XFree86: doctools/sgmlformat/sgmlfmt/sgmlfmt.pl,v 1.14 1999/07/07 09:03:16 dawes Exp $
 
 # Format an sgml document tagged according to the linuxdoc DTD.
 # by John Fieber <jfieber@freebsd.org> for the FreeBSD documentation
 # project.  
 
+
 require 'newgetopt.pl';
 
 #
@@ -88,7 +89,7 @@ sub usage {
     print "sgmlfmt [-d <doctype>] -f <format> [-i <namea> ...] [-links]\n";
     print "  [-e encoding] [-hdr file] [-ftr file] [-b] [-n] [-l level] file\n";
     print "where <doctype> is one of: linuxdoc (default), docbook.\n";
-    print "and <format> is one of: ascii, html, koi8-r, latin1, nippon, ps, roff\n";
+    print "and <format> is one of: ascii, html, koi8-r, latin1, ps, roff\n";
 }
 
 #
@@ -158,10 +159,6 @@ sub gen_roff {
 # Generate something from roff output
 #
 
-# Extra groff options required on some systems
-
-$groff_opts = "";
-
 sub do_groff {
     local($driver, $postproc, $preamble) = @_;
     @cleanfiles = (@cleanfiles, "${fileroot}.trf", "${fileroot}.tmp", 
@@ -176,8 +173,7 @@ sub do_groff {
     close(outfile);
     &exitiferror($?);
     
-    open(infile, "env GROFF_NO_SGR=1 groff ${groff_opts} -T ${driver} " .
-	   "-t -M ${sgmldir}/tmac " .
+    open(infile, "groff -T ${driver} -t -M ${sgmldir}/tmac " .
 	   "${fileroot}.trf ${postproc} |");
     open(outfile, "> ${fileroot}.${driver}");
     if ("$opt_n") {
@@ -198,8 +194,7 @@ sub do_groff {
     # in the file and we need a second pass to resolve them correctly.
 
     if (stat("${fileroot}.tmp")) {
-	open(infile, "env GROFF_NO_SGR=1 groff ${groff_opts} -T ${driver} " .
-		"-t -M ${sgmldir}/tmac " .
+	open(infile, "groff -T ${driver} -t -M ${sgmldir}/tmac " .
 		"${fileroot}.trf ${postproc} |");
 	open(outfile, "> ${fileroot}.${driver}");
 	while (<infile>) {
@@ -217,13 +212,6 @@ sub do_groff {
 	$/=$save;
     }
     &exitiferror($?);
-
-    if ( $opt_f eq "nippon" ) {
-       system("nkf -e ${fileroot}.${driver} >${fileroot}.euc-jp");
-       unlink("${fileroot}.${driver}");
-    }
-    &exitiferror($?);
-
 }
 
 #
@@ -773,7 +761,7 @@ sub main {
     	$decl = "-c " . $sgmldir . "/linuxdoc/catalog";
     }
 
-    if ($opt_b || $opt_f eq "nippon" || $opt_e eq "euc-jp") {
+    if ($opt_b) {
 	$colcmd = "col -bx";
     }
     else {
@@ -784,13 +772,6 @@ sub main {
     } else {
 	$nroff_preamble = ".nr NOPBRK 0\n";
     }
-
-    # See if groff has the -U flag.  We need to use it when it is present.
-
-    if (system("groff -U /dev/null > /dev/null 2>&1") == 0) {
-	$groff_opts = "-U";
-    }
-
     # Generate the output
     if ($opt_f eq 'html') {
     	# Set the character encoding
@@ -826,9 +807,6 @@ sub main {
     elsif ($opt_f eq 'koi8-r') {
     	&do_groff("koi8-r", "| $colcmd", $nroff_preamble);
     }
-    elsif ($opt_f eq 'nippon') {
-    	&do_groff("nippon", "| $colcmd", $nroff_preamble);
-    }
     elsif ($opt_f eq 'ps') {
     	&do_groff("ps", "", "");
     }
